@@ -7,7 +7,6 @@ from rest_framework.routers import SimpleRouter
 from rest_framework import serializers
 from django.urls.conf import path
 from rest_framework.decorators import MethodMapper
-from dataclasses import field
 from django.db.models.fields.related import ManyToManyField, ForeignKey
 
 class DefaultSite():
@@ -120,6 +119,9 @@ class DefaultSite():
         args = {
         }
         self._patch_fields(admin, args)
+        for inline in admin.inlines:
+            print(inline.fk_name)
+            # print(inline.model._meta.model_name.lower())
         serializer_class: serializers.ModelSerializer = type('', (GeneralSerializer, ), args)
         serializer_class._admin = admin
         serializer_class.Meta = type('', (), {})
